@@ -363,7 +363,7 @@ uves_utl_remove_crh_single( cpl_parameterlist   *   parlist,
 
     uves_msg("nraw=%d",nraw);
 
-    check_nomsg(frame_on=cpl_frameset_get_first(raw_on));
+    check_nomsg(frame_on=cpl_frameset_get_frame(raw_on,0));
     check_nomsg(next1=cpl_frame_get_nextensions(frame_on));
     check_nomsg(name1=cpl_frame_get_filename(frame_on));
     check_nomsg(plist1=cpl_propertylist_load(name1,0));
@@ -392,7 +392,7 @@ uves_utl_remove_crh_single( cpl_parameterlist   *   parlist,
       
       } else {
 
-	frame_off=cpl_frameset_get_first(raw_off);
+	frame_off=cpl_frameset_get_frame(raw_off,0);
 	next2=cpl_frame_get_nextensions(frame_off);
         /* check that raw frame and bias are coherent else exit */
         if(next2 != next1) {
