@@ -38,7 +38,7 @@
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
 #endif
-#include <flames_lfit.h>
+//#include <flames_lfit.h>
 #include <flames_midas_def.h>   /* MIDAS environment interface functions */
 #include <flames_corvel.h>        /* FLAMES-UVES functions */
 #include <flames_newmatrix.h>   /* FLAMES-UVES functions for array manipolation */
@@ -218,7 +218,7 @@ int flames_corvel(const char *IN_A,
   int    weight_id=0;
 
   int i=0;
-  int counter=0;
+
 
   double  tmp_dbl=0;
 
@@ -465,7 +465,7 @@ int flames_corvel(const char *IN_A,
        wsize,wcenter,weight
        If no condition is given keep the vectors intact
     */
-     counter=0;
+     int counter=0;
      for(i=1;i<in_msk_nrow;i++) {
        if (msk_hole_wgt[counter] > in_msk_wgt_min) {
           msk_hole_siz_selw[counter] = msk_hole_siz[i];  
@@ -929,10 +929,10 @@ do_ccf_f(double* mask_ll,double* mask_d,double* mask_w,double* sp_ll,
 
   int i=0;
   int j=0;
-  int first_hole;
+
   int midas_unit = 0;
   int sp_ll_sz = in_ima_ncol;
-  int guess=0;
+
   int ndeg=6;
 
   /* Function prototype */
@@ -1007,8 +1007,8 @@ do_ccf_f(double* mask_ll,double* mask_d,double* mask_w,double* sp_ll,
     (see NR F77 chapter 3.4)
     */
     
-    first_hole=hunt(msk_blu-1, in_msk_nrow, sp_ll[0],0);
-    guess=first_hole;
+    int first_hole=hunt(msk_blu-1, in_msk_nrow, sp_ll[0],0);
+    int guess=first_hole;
 
     for(j=0;j<in_msk_nrow;j++) {
       //for(j=0;j<3;j++) {
@@ -1048,15 +1048,6 @@ do_ccf_f(double* mask_ll,double* mask_d,double* mask_w,double* sp_ll,
   ia[3]=1;
   ia[4]=0;
 
-  /*
-  lfit(xfit,yfit,sfit,rv_ccf_size,aa,ia,3,covar,&chisq,fgauss); 
-  non_lfit(xfit,yfit,sfit,rv_ccf_size,aa,ndeg,ia,4,fgauss,erraa,&chisq); 
-  alambda=-1.0;
-  mrqmin(xfit,yfit,sfit,rv_ccf_size,aa,ndeg,ia,mfit,covar,alpha,&chisq,
-         fgauss,&alambda); 
-  */
-
-
   gaussian_fit(rv_ccf,ccf_o,rv_ccf_size,&norm,&cen,&sig,&fwhm);
 
   /* write output in descriptor */
@@ -1218,15 +1209,15 @@ fit_ccf(double* rv_ccf,double* ccf_nor,int type,double* ccf_res,
 int 
 hunt(double* xx, int n, double x, int jlo) {
 
-    int jm, jhi, inc;
-    int ascnd;
+    int jhi;
+
     
-    ascnd=(xx[n] >= xx[1]);
+    int ascnd=(xx[n] >= xx[1]);
     if (jlo <= 0 || jlo >n) {
         jlo=0;
         jhi=n+1;
     } else {
-        inc=1;
+        int inc=1;
         if ((x>=xx[jlo]) == ascnd) {
             if (jlo == n) return jlo-1;
             jhi=jlo+1;
@@ -1257,7 +1248,7 @@ hunt(double* xx, int n, double x, int jlo) {
         }
     }
     while ((jhi-jlo) != 1) {
-        jm=(jhi+jlo) >> 1;
+        int jm=(jhi+jlo) >> 1;
         if ( (x >= xx[jm]) ==ascnd)
             jlo=jm;
         else
