@@ -204,6 +204,14 @@ flames_reduce_vcorrel(const char* sci_pfx,
       check_nomsg(nrow=cpl_table_get_nrow(cvel_ord_tbl));
 
       check_nomsg(cpl_table_fill_column_window_int(cvel_ord_tbl,"ORDER",0,nrow,ord));
+      if(ord==ord_min) {
+         const char* unit=cpl_table_get_column_unit(cvel_ord_tbl,"ccf_pos");
+         cpl_table_set_column_unit(cvel_tbl,"ccf_pos",unit);
+         unit=cpl_table_get_column_unit(cvel_ord_tbl,"ccf_nrm");
+         cpl_table_set_column_unit(cvel_tbl,"ccf_nrm",unit);
+         unit=cpl_table_get_column_unit(cvel_ord_tbl,"ccf_out");
+         cpl_table_set_column_unit(cvel_tbl,"ccf_out",unit);
+      }
       check_nomsg(cpl_table_insert(cvel_tbl,cvel_ord_tbl,row_pos));
       row_pos+=nrow;
 
