@@ -22,326 +22,6 @@
  * $Date: 2011-12-08 13:55:51 $
  * $Revision: 1.148 $
  * $Name: not supported by cvs2svn $
- * $Log: not supported by cvs2svn $
- * Revision 1.147  2010/11/26 07:41:34  amodigli
- * added uves_scired_wmap_filename()
- *
- * Revision 1.146  2010/09/24 09:32:03  amodigli
- * put back QFITS dependency to fix problem spot by NRI on FIBER mode (with MIDAS calibs) data
- *
- * Revision 1.144  2010/06/07 17:41:49  amodigli
- * added uves_scired_fluxcal_science_noappend_filename(),uves_scired_fluxcal_error_noappend_filename()
- *
- * Revision 1.143  2010/06/07 13:24:20  amodigli
- * Fixed typo in PRO.CATG and PIPEFILE of products in case of merging option is noappend: NOAPPEND-->NONMERGED
- *
- * Revision 1.142  2010/06/07 11:12:02  amodigli
- * added uves_scired_red_noappend_error_filename()
- *
- * Revision 1.141  2010/06/04 09:50:10  amodigli
- * added UVES_RED_NOAPPEND_STD, uves_response_red_noappend_standard_filename() uves_scired_red_noappend_science_filename()
- *
- * Revision 1.140  2010/05/19 13:28:51  amodigli
- * rename uves_extraction_quality_standard_filename->uves_order_extract_qc_standard_filename, UVES_EXTRACTION_QUALITY->UVES_ORDER_EXTRACT_QC
- *
- * Revision 1.139  2010/05/18 17:09:24  amodigli
- * added UVES_EXTRACTION_QUALITY and uves_extraction_quality_standard_filename
- *
- * Revision 1.138  2009/02/20 18:21:12  amodigli
- * added RAW_IMA
- *
- * Revision 1.137  2009/01/02 08:30:03  amodigli
- * added uves_contains_frames_kind
- *
- * Revision 1.136  2008/08/29 09:52:26  amodigli
- * fixed compiler warning
- *
- * Revision 1.135  2008/06/26 08:25:55  amodigli
- * added uves_local_filename
- *
- * Revision 1.134  2007/11/26 15:26:59  amodigli
- * added FLAMES_INFO_TABLE
- *
- * Revision 1.133  2007/11/19 08:07:06  amodigli
- * cleaned
- *
- * Revision 1.132  2007/11/13 16:20:59  amodigli
- * added UVES_ORD_TAB to remove name clashes between order tables from FIBER and ECHELLE mode
- *
- * Revision 1.131  2007/10/30 17:45:03  jmlarsen
- * Added WEIGHTS_<chip> images to support object weighted arclamp extraction
- *
- * Revision 1.130  2007/10/17 14:58:48  amodigli
- * added uves_check_if_format_is_midas
- *
- * Revision 1.129  2007/09/19 11:09:49  amodigli
- * Now FLAMES_FIB_FF_DT is a macro
- *
- * Revision 1.128  2007/09/11 17:08:07  amodigli
- * added uves_polynomial_convert_from_plist_midas from uves_utils_polynomial.h
- *
- * Revision 1.127  2007/09/06 14:14:38  amodigli
- * added uves_scired_ff_variance_2d_filename
- *
- * Revision 1.126  2007/08/16 13:21:15  amodigli
- * added uves_scired_red_2d_error_filename
- *
- * Revision 1.125  2007/08/16 06:49:47  amodigli
- * added uves_vector_to_image
- *
- * Revision 1.124  2007/08/10 12:10:35  amodigli
- * changed 2d extraction product file names as by DFS04196
- *
- * Revision 1.123  2007/08/02 15:18:10  amodigli
- * added possibility of FLAMES_SLIT_FF_BN4
- *
- * Revision 1.122  2007/07/23 06:30:50  amodigli
- * added FLAMES_FIB_FF_DT
- *
- * Revision 1.121  2007/07/03 12:39:13  amodigli
- * added FLAMES_CORVEL_MASK FLAMES_SCI_SIM_RED
- *
- * Revision 1.120  2007/06/26 13:34:43  jmlarsen
- * Exported function for FLAMES
- *
- * Revision 1.119  2007/06/25 07:16:55  jmlarsen
- * Fixed definition of FLAMES_FIB_FF_BP
- *
- * Revision 1.118  2007/06/25 05:54:45  amodigli
- * added FIB_LINE_TABLE_MIDAS
- *
- * Revision 1.117  2007/06/22 16:04:01  jmlarsen
- * Fixed one FLAMES tag
- *
- * Revision 1.116  2007/06/22 15:49:27  jmlarsen
- * Fixed FLAMES product tags
- *
- * Revision 1.115  2007/06/22 14:50:45  jmlarsen
- * Optionally save height=1 images as NAXIS=1
- *
- * Revision 1.114  2007/06/22 09:30:10  jmlarsen
- * Allow saving CPL_TYPE_INT images as 16 or 32 bit FITS
- *
- * Revision 1.113  2007/06/21 15:12:57  amodigli
- * added FLAMES sci product types
- *
- * Revision 1.112  2007/06/06 08:17:33  amodigli
- * replace tab with 4 spaces
- *
- * Revision 1.111  2007/05/16 11:47:18  amodigli
- * added FLAMES_SCI_COM_RED
- *
- * Revision 1.110  2007/05/03 15:19:12  jmlarsen
- * Added const version of uves_load_linetable()
- *
- * Revision 1.109  2007/04/26 13:19:13  jmlarsen
- * Exported function copy_if_possible
- *
- * Revision 1.108  2007/04/24 16:44:26  amodigli
- * changed interface uves_load_ordertable to return also extention table
- *
- * Revision 1.107  2007/04/24 12:50:29  jmlarsen
- * Replaced cpl_propertylist -> uves_propertylist which is much faster
- *
- * Revision 1.106  2007/04/23 06:59:29  amodigli
- * added uves_save_imagelist
- *
- * Revision 1.105  2007/04/03 06:28:26  amodigli
- * uves_load_ordertable provides now fibre_mask and fibre_pos if appropriate
- *
- * Revision 1.104  2007/03/20 15:39:54  amodigli
- * added FLAMES tags
- *
- * Revision 1.103  2007/03/15 15:04:37  jmlarsen
- * Allow spaces in HISTORY keyword string values
- *
- * Revision 1.102  2007/02/09 13:36:06  jmlarsen
- * Added function to load ref_flat
- *
- * Revision 1.101  2007/02/08 07:33:17  jmlarsen
- * Added uves_load_cd_align()
- *
- * Revision 1.100  2007/01/17 13:25:41  jmlarsen
- * Added uves_load_image()
- *
- * Revision 1.99  2007/01/10 12:37:18  jmlarsen
- * Exported function to warn about mismatching calibration frames
- *
- * Revision 1.98  2007/01/09 17:45:42  amodigli
- * added uves_check_rec_status
- *
- * Revision 1.97  2006/12/12 12:09:12  jmlarsen
- * Added function to load corvel table
- *
- * Revision 1.96  2006/12/07 08:23:02  jmlarsen
- * uves_load_raw_imagelist: support FLAMES
- *
- * Revision 1.95  2006/12/01 08:26:58  jmlarsen
- * Load FLAMES order table oshift/yshift
- *
- * Revision 1.94  2006/11/24 16:21:32  jmlarsen
- * Added FIB_LINE_TABLE_x
- *
- * Revision 1.93  2006/11/22 08:41:12  jmlarsen
- * Exported and fixed bug in uves_read_midas_array
- *
- * Revision 1.91  2006/11/22 08:22:29  jmlarsen
- * Set message level according to preprocessor symbol
- *
- * Revision 1.90  2006/11/16 14:09:27  jmlarsen
- * Fixed definition of FLAMES order table tag
- *
- * Revision 1.89  2006/11/15 15:02:14  jmlarsen
- * Implemented const safe workarounds for CPL functions
- *
- * Revision 1.87  2006/11/15 14:04:08  jmlarsen
- * Removed non-const version of parameterlist_get_first/last/next which is already
- * in CPL, added const-safe wrapper, unwrapper and deallocator functions
- *
- * Revision 1.86  2006/11/13 12:44:31  jmlarsen
- * Support FLAMES FIB_ARC_LAMP_RED frames
- *
- * Revision 1.85  2006/11/07 14:01:12  jmlarsen
- * Moved flames_load_ functions to separate source file
- *
- * Revision 1.84  2006/11/03 15:01:21  jmlarsen
- * Killed UVES 3d table module and use CPL 3d tables
- *
- * Revision 1.83  2006/10/24 14:05:25  jmlarsen
- * Generalized load functions to support FLAMES
- *
- * Revision 1.82  2006/10/19 13:53:25  jmlarsen
- * Changed guess line table tag to LINE_GUESS_TAB
- *
- * Revision 1.81  2006/10/12 11:37:28  jmlarsen
- * Temporarily disabled FLAMES code generation
- *
- * Revision 1.80  2006/10/02 08:34:06  jmlarsen
- * Added REF_TFLAT
- *
- * Revision 1.79  2006/09/27 13:13:24  jmlarsen
- * Use dynamic memory allocation to store bad pixels
- *
- * Revision 1.78  2006/09/20 15:42:18  jmlarsen
- * Implemented MASTER_RESPONSE support
- *
- * Revision 1.77  2006/09/20 10:57:19  jmlarsen
- * Fixed typo
- *
- * Revision 1.76  2006/09/20 07:26:54  jmlarsen
- * Shortened max line length
- *
- * Revision 1.75  2006/09/19 14:25:32  jmlarsen
- * Propagate FITS keywords from master flat, not science, to WCALIB_FLAT_OBJ
- *
- * Revision 1.74  2006/09/19 07:12:58  jmlarsen
- * Exported function uves_write_statistics
- *
- * Revision 1.73  2006/09/14 08:46:51  jmlarsen
- * Added support for TFLAT, SCREEN_FLAT frames
- *
- * Revision 1.72  2006/09/11 08:19:10  jmlarsen
- * Renamed identifier reserved by POSIX
- *
- * Revision 1.71  2006/08/24 11:36:58  jmlarsen
- * Write recipe start/stop time to header
- *
- * Revision 1.70  2006/08/17 13:56:52  jmlarsen
- * Reduced max line length
- *
- * Revision 1.69  2006/08/11 08:59:41  jmlarsen
- * Take into account the different meanings of line table 'Y' column
- *
- * Revision 1.68  2006/08/07 14:42:02  jmlarsen
- * Implemented on-the-fly correction of a line table when its order
- * numbering is inconsistent with the order table (DFS02694)
- *
- * Revision 1.67  2006/08/07 12:14:19  jmlarsen
- * Removed unused function
- *
- * Revision 1.66  2006/08/01 14:43:36  amodigli
- * fixed bug loading fitsheader in uves_load_masterformatcheck
- *
- * Revision 1.65  2006/07/31 06:29:05  amodigli
- * added flames_load_frame_index
- *
- * Revision 1.64  2006/07/14 12:20:10  jmlarsen
- * Added LINE_INTMON_TABLE
- *
- * Revision 1.63  2006/06/26 07:54:15  amodigli
- * flames_load_image flames_load_table
- *
- * Revision 1.62  2006/06/23 15:31:32  amodigli
- * added useful stuff for flames
- *
- * Revision 1.61  2006/06/22 15:25:35  amodigli
- * changes for flames_cal_prep_sff_ofpos
- *
- * Revision 1.60  2006/06/19 06:51:14  amodigli
- * added support flames-old format
- *
- * Revision 1.59  2006/06/16 08:22:01  jmlarsen
- * Manually propagate ESO.DET. keywords from 1st/2nd input header
- *
- * Revision 1.58  2006/06/13 11:55:06  jmlarsen
- * Shortened max line length
- *
- * Revision 1.57  2006/06/06 09:04:14  jmlarsen
- * Bugfix: UVES_CHIP_REDU -> UVES_CHIP_REDL
- *
- * Revision 1.56  2006/06/06 08:40:10  jmlarsen
- * Shortened max line length
- *
- * Revision 1.55  2006/05/22 06:47:15  amodigli
- * fixed some bugs on msflat
- *
- * Revision 1.54  2006/05/19 13:07:52  amodigli
- * modified to support SFLATs
- *
- * Revision 1.53  2006/05/17 09:54:55  amodigli
- * added supposr SFLATs
- *
- * Revision 1.52  2006/05/15 06:09:52  amodigli
- * added support for some FLAMES input frames
- *
- * Revision 1.51  2006/04/25 14:58:48  amodigli
- * added paf creation functionalities
- *
- * Revision 1.50  2006/04/24 09:19:01  jmlarsen
- * Simplified code
- *
- * Revision 1.49  2006/04/06 13:13:04  jmlarsen
- * Added const modifier
- *
- * Revision 1.48  2006/04/06 12:56:50  jmlarsen
- * Added support for PDARK, IFLAT, DLFAT frames
- *
- * Revision 1.47  2006/04/06 11:48:17  jmlarsen
- * Support for SCI_POINT_-, SCI_EXTND_- and SCI_SLICER-frames
- *
- * Revision 1.46  2006/04/06 09:48:15  amodigli
- * changed uves_frameset_insert interface to have QC log
- *
- * Revision 1.45  2006/04/06 08:31:15  jmlarsen
- * Added support for reading MASTER_DFLAT, MASTER_IFLAT, MASTER_PDARK
- *
- * Revision 1.44  2006/03/24 14:19:19  jmlarsen
- * Recognize background tables
- *
- * Revision 1.43  2006/03/06 09:22:43  jmlarsen
- * Added support for reading MIDAS line tables with MIDAS tags
- *
- * Revision 1.42  2006/02/15 13:19:15  jmlarsen
- * Reduced source code max. line length
- *
- * Revision 1.41  2006/01/09 15:22:55  jmlarsen
- * Removed some warnings
- *
- * Revision 1.40  2006/01/03 16:56:53  amodigli
- * Added MASTER_ARC_FORM
- *
- * Revision 1.39  2005/12/19 16:17:56  jmlarsen
- * Replaced bool -> int
  *
  */
 
@@ -356,6 +36,7 @@
 #include <uves_utils_polynomial.h>
 #include <uves_chip.h>
 #include <uves_utils.h>
+#include <uves_globals.h>
 #include <cpl.h>
 
 #include <stdbool.h>
@@ -1234,7 +915,9 @@ char *uves_scired_resampled_filename(enum uves_chip chip);
 char *uves_scired_resampled_2d_filename(enum uves_chip chip);
 char *uves_scired_resampledmf_filename(enum uves_chip chip);
 char *uves_scired_rebinned_filename(enum uves_chip chip);
+char *uves_scired_rebinned_error_filename(enum uves_chip chip);
 char *uves_scired_rebinned_2d_filename(enum uves_chip chip);
+char *uves_scired_rebinned_2d_error_filename(enum uves_chip chip);
 char *uves_scired_ordertrace_filename(enum uves_chip chip);
 char *uves_scired_wmap_filename(enum uves_chip chip);
 char *uves_scired_crmask_filename(enum uves_chip chip);
