@@ -21,193 +21,6 @@
  * $Author: amodigli $
  * $Date: 2011-11-02 15:43:23 $
  * $Revision: 1.62 $
- * $Name: not supported by cvs2svn $
- * $Log: not supported by cvs2svn $
- * Revision 1.61  2011/09/09 09:56:21  amodigli
- * using irplib_mkmaster() functionality
- *
- * Revision 1.60  2010/09/24 09:49:18  amodigli
- * added info on mean master bias level as asked by Daniel
- *
- * Revision 1.59  2010/09/24 09:32:03  amodigli
- * put back QFITS dependency to fix problem spot by NRI on FIBER mode (with MIDAS calibs) data
- *
- * Revision 1.57  2010/08/30 14:16:08  amodigli
- * fixed problem computing QC.RON.OUTi.RAW (DFS09268)
- *
- * Revision 1.56  2010/06/11 11:40:46  amodigli
- * rename method to stack_method
- *
- * Revision 1.55  2010/06/02 09:20:44  amodigli
- * added correction of bias level before computation of median stack-then put back mean of levels on master bias
- *
- * Revision 1.54  2010/03/31 10:09:59  amodigli
- * added description
- *
- * Revision 1.53  2010/03/22 15:58:02  amodigli
- * added params and possibility to compute master as mean stack
- *
- * Revision 1.52  2009/10/29 17:16:29  amodigli
- * added param to specify if red cdd is new/old in call to uves_get_badpix
- *
- * Revision 1.51  2008/09/29 06:56:48  amodigli
- * add #include <string.h>
- *
- * Revision 1.50  2008/05/01 09:51:03  amodigli
- * fixed compiler warnings
- *
- * Revision 1.49  2008/04/02 14:02:02  amodigli
- * fixed compilation warnings
- *
- * Revision 1.48  2008/03/28 08:53:43  amodigli
- * IRPLIB_CONCAT2X-->UVES_CONCAT2X
- *
- * Revision 1.47  2008/03/04 15:20:59  amodigli
- * fixed redchain problem with clean_traps parameter
- *
- * Revision 1.46  2008/03/03 16:34:03  amodigli
- * added parameter to control trap column correction
- *
- * Revision 1.45  2008/02/15 12:43:49  amodigli
- * allow lower/upper chip for parameter process_chip
- *
- * Revision 1.44  2007/10/05 16:01:44  amodigli
- * using proces_chip parameter to process or not a given RED chip
- *
- * Revision 1.43  2007/08/21 13:08:26  jmlarsen
- * Removed irplib_access module, largely deprecated by CPL-4
- *
- * Revision 1.42  2007/06/11 13:28:26  jmlarsen
- * Changed recipe contact address to cpl at eso.org
- *
- * Revision 1.41  2007/06/08 13:06:16  jmlarsen
- * Send bug reports to Andrea
- *
- * Revision 1.40  2007/06/06 08:17:33  amodigli
- * replace tab with 4 spaces
- *
- * Revision 1.39  2007/05/22 11:31:35  jmlarsen
- * Removed image plotting functionality
- *
- * Revision 1.38  2007/04/24 12:50:29  jmlarsen
- * Replaced cpl_propertylist -> uves_propertylist which is much faster
- *
- * Revision 1.37  2007/02/27 07:42:21  jmlarsen
- * Fixed bug when counting non-rejected pixels
- *
- * Revision 1.36  2007/02/26 10:15:56  jmlarsen
- * Be robust against the unlikely case that there are no good pixels to compute QC stats
- *
- * Revision 1.35  2007/02/23 13:32:43  jmlarsen
- * Change QC computation to exactly match MIDAS' STAT/IMAGE
- *
- * Revision 1.34  2007/02/09 13:37:43  jmlarsen
- * Enable calling from uves_cal_mkmaster
- *
- * Revision 1.33  2007/02/09 08:57:29  jmlarsen
- * Do not use CPL_PIXEL_MAXVAL which works only for integer images
- *
- * Revision 1.32  2007/02/09 08:14:16  jmlarsen
- * Do not use CPL_PIXEL_MAXVAL which works only for integer images
- *
- * Revision 1.31  2007/01/10 12:37:39  jmlarsen
- * Removed obsolete comments
- *
- * Revision 1.30  2006/12/07 08:23:23  jmlarsen
- * uves_load_raw_imagelist: support FLAMES
- *
- * Revision 1.29  2006/11/15 15:02:14  jmlarsen
- * Implemented const safe workarounds for CPL functions
- *
- * Revision 1.27  2006/11/15 14:04:08  jmlarsen
- * Removed non-const version of parameterlist_get_first/last/next which is 
- * already in CPL, added const-safe wrapper, unwrapper and deallocator functions
- *
- * Revision 1.26  2006/11/06 15:19:41  jmlarsen
- * Removed unused include directives
- *
- * Revision 1.25  2006/10/17 12:33:02  jmlarsen
- * Added semicolon at UVES_RECIPE_DEFINE invocation
- *
- * Revision 1.24  2006/10/09 13:01:13  jmlarsen
- * Use macro to define recipe interface functions
- *
- * Revision 1.23  2006/09/19 14:31:10  jmlarsen
- * uves_insert_frame(): use bitmap to specify which image statistics keywords must 
- * be computed
- *
- * Revision 1.22  2006/09/19 06:55:52  jmlarsen
- * Changed interface of uves_frameset to optionally write image statistics kewwords
- *
- * Revision 1.21  2006/08/24 11:36:37  jmlarsen
- * Write recipe start/stop time to header
- *
- * Revision 1.20  2006/08/18 13:35:42  jmlarsen
- * Fixed/changed QC parameter formats
- *
- * Revision 1.19  2006/08/17 13:56:53  jmlarsen
- * Reduced max line length
- *
- * Revision 1.18  2006/08/11 14:56:05  amodigli
- * removed Doxygen warnings
- *
- * Revision 1.17  2006/08/10 10:52:11  jmlarsen
- * Bugfix in comparison of chip id
- *
- * Revision 1.16  2006/07/14 12:19:28  jmlarsen
- * Support multiple QC tests per product
- *
- * Revision 1.15  2006/07/03 13:09:24  amodigli
- * adjusted description display layout
- *
- * Revision 1.14  2006/07/03 12:58:34  jmlarsen
- * Support flagging instead of interpolating bad pixels
- *
- * Revision 1.13  2006/06/22 08:58:33  jmlarsen
- * Use correct port number for QC
- *
- * Revision 1.12  2006/06/16 08:25:45  jmlarsen
- * Manually propagate ESO.DET. keywords from 1st/2nd input header
- *
- * Revision 1.11  2006/06/07 09:01:28  amodigli
- * added some doc
- *
- * Revision 1.10  2006/06/06 08:40:50  jmlarsen
- * Changed order of messages
- *
- * Revision 1.9  2006/05/12 15:40:08  jmlarsen
- * Fixed mixed code declarations
- *
- * Revision 1.8  2006/05/09 15:42:00  amodigli
- * added QC log
- *
- * Revision 1.7  2006/05/08 16:47:15  amodigli
- * added QC
- *
- * Revision 1.6  2006/05/08 15:38:46  amodigli
- * made changes to have port-id
- *
- * Revision 1.5  2006/05/05 14:33:22  jmlarsen
- * Removed debugging message
- *
- * Revision 1.4  2006/05/05 13:54:52  jmlarsen
- * Removed warnings about unused variables
- *
- * Revision 1.3  2006/04/20 10:47:39  amodigli
- * added qclog
- *
- * Revision 1.2  2006/04/06 09:48:15  amodigli
- * changed uves_frameset_insert interface to have QC log
- *
- * Revision 1.1  2006/02/03 07:46:30  jmlarsen
- * Moved recipe implementations to ./uves directory
- *
- * Revision 1.42  2006/01/19 08:47:24  jmlarsen
- * Inserted missing doxygen end tag
- *
- * Revision 1.41  2005/12/19 16:17:55  jmlarsen
- * Replaced bool -> int
- *
  */
 
 #ifdef HAVE_CONFIG_H
@@ -417,6 +230,8 @@ uves_mbias_process_chip(const cpl_imagelist *raw_images,
            "Error reading exposure time");
     }
     exposure_time /= nraw;
+
+    uves_pfits_set_extname(mbias_header,"Master bias");
     
     check( uves_pfits_set_exptime(mbias_header, exposure_time),
        "Error setting master bias exposure time");
