@@ -406,6 +406,7 @@ uves_polynomial_convert_to_table(const polynomial *p)
     cpl_table_new_column(t, COLUMN_ORDER2, CPL_TYPE_INT);
     cpl_table_new_column(t, COLUMN_COEFF , CPL_TYPE_DOUBLE);
 
+
     row = 0;
 
     /* First write the shifts, write non-garbage to coeff columns (which are not used) */
@@ -450,6 +451,9 @@ uves_polynomial_convert_to_table(const polynomial *p)
         row++;
     }
     }
+    cpl_table_set_column_unit(t, COLUMN_ORDER1 , " ");
+    cpl_table_set_column_unit(t, COLUMN_ORDER2 , " ");
+    cpl_table_set_column_unit(t, COLUMN_COEFF , " ");
 
   cleanup:
     return t;
