@@ -277,6 +277,17 @@ uves_wavecal_identify(cpl_table *linetable,
     cpl_table_set_column_invalid(linetable, "Ident", 0, cpl_table_get_nrow(linetable));
     cpl_table_set_column_invalid(linetable, "dIdent",0, cpl_table_get_nrow(linetable));
     
+    cpl_table_set_column_unit(linetable,LINETAB_LAMBDAC,"Angstrom" );
+    cpl_table_set_column_unit(linetable,"dLambdaC","Angstrom" );
+    cpl_table_set_column_unit(linetable,LINETAB_PIXELSIZE,"Angstrom" );
+    cpl_table_set_column_unit(linetable,LINETAB_RESIDUAL,"Angstrom" );
+    cpl_table_set_column_unit(linetable,"Residual_pix","Angstrom" );
+    cpl_table_set_column_unit(linetable,"Lambda_candidate","Angstrom" );
+    cpl_table_set_column_unit(linetable,"dLambda_candidate","Angstrom" );
+    cpl_table_set_column_unit(linetable,"dLambda_cat_sq","Angstrom" );
+    cpl_table_set_column_unit(linetable,"dLambda_nn_sq","Angstrom" );
+    cpl_table_set_column_unit(linetable,"Ident","Angstrom" );
+    cpl_table_set_column_unit(linetable,"dIdent","Angstrom" );
     /* Residuals are not calculated because 'Ident' is invalid */
     check( compute_lambda(linetable, guess_dispersion, NULL, false), 
            "Error applying dispersion relation");
@@ -853,8 +864,8 @@ identify_lines(cpl_table *linetable, const cpl_table *line_refer, double ALPHA)
      *                          and 2 neigbours in line catalogue
      */
     {
-        double lambda_com_prev, lambda_com_next;
-        int order_prev, order_next;
+
+
         double lambda_cat_prev, lambda_cat_next;
 
         nn_distance_sq = DBL_MAX;
@@ -862,9 +873,9 @@ identify_lines(cpl_table *linetable, const cpl_table *line_refer, double ALPHA)
         /* Read previous and next rows of line table */
         if (row >= 1) 
         {
-            order_prev      = cpl_table_get_int   (
+            int order_prev      = cpl_table_get_int   (
             linetable, "Order"  , row - 1, NULL);
-            lambda_com_prev = cpl_table_get_double(
+            double lambda_com_prev = cpl_table_get_double(
             linetable, LINETAB_LAMBDAC, row - 1, NULL);
             
             if (order == order_prev) 
@@ -878,9 +889,9 @@ identify_lines(cpl_table *linetable, const cpl_table *line_refer, double ALPHA)
 
         if (row <= linetable_size - 2) 
         {
-            order_next      = cpl_table_get_int   (linetable, "Order", 
+            int order_next      = cpl_table_get_int   (linetable, "Order",
                                row + 1, NULL);
-            lambda_com_next = cpl_table_get_double(linetable, LINETAB_LAMBDAC,
+            double lambda_com_next = cpl_table_get_double(linetable, LINETAB_LAMBDAC,
                                row + 1, NULL);
             
             if (order == order_next) 
